################################################################################
## Customer    : MMC Networks
## Project     : 5710
## Description : Procedure: get_segment_delay -to  [-from ][-verbose]
## Author      : Robert Scott, Synopsys
## PT Version  : 2000.05
##             :
## History     : 1/31/00  Initial script development
##             :
## Notes       : This utility returns a point-to-point delay value between two
##             : points. It is useful as a stand-alone or nested command, for
##             : instance to set a clock latency based on a related buffer
##             : string delay.
##             :
################################################################################

proc get_segment_delay { args } {

set results(-from) "NULL"
set results(-to) "NULL"
set results(-verbose) false

parse_proc_arguments -args $args results

set frompoint $results(-from)
set topoint $results(-to)
set verbose $results(-verbose)

# Note: Assume that rising edge feedback is of primary interest,
set dtype "max_rise"

set delta_time 0
set from_time 0
set to_time 0
redirect /dev/null \
 { set rcs_string {$Id: get_segment_delay.proc,v 1.2 2001/02/13 rscott Exp $} }
redirect /dev/null { set version [lindex $rcs_string 2] }
if { $verbose } {
   echo "Running version $version"
}

# First, get the path of interest. Use the -though option for most robust
# path retrieval.
if { $frompoint == "NULL" } {
   set mypath [get_timing_paths -thr $topoint -delay_type $dtype -max_path 1]
} else {
#   set mypath [get_timing_paths -thr " $frompoint $topoint " \
#    -delay_type $dtype -max_path 1]
   set mypath [get_timing_paths -through $frompoint -to $topoint \
    -delay_type $dtype -max_path 1]
}
echo "Number of paths is [sizeof_coll $mypath]"

set pts [get_attribute $mypath points]

foreach_in_collection pt $pts {
 set ptname [get_attribute [get_attribute $pt object] full_name]
 if { $verbose } {
    echo "Next point is $ptname and arrival is [get_attribute $pt arrival]"
 }
 if { $ptname == $frompoint } {
    set from_time [get_attribute $pt arrival]
 } elseif { $ptname == $topoint } {
    set to_time [get_attribute $pt arrival]
 }
}

set delta_time [expr $to_time - $from_time]

if { $verbose } { 
   echo "Point to point delay from $frompoint to $topoint is $delta_time."
}

return $delta_time
          
}

define_proc_attributes get_segment_delay -info \
 "Get the point to point delay of a path segment" -define_args \
   {
    {-verbose "see detailed point info along the path" "" boolean optional}
    {-from "pin or port" "from_point" string optional }
    {-to "pin or port" "to_point" string required }
   }
